# compute_location.py
# author: Marko Borazio for ESS, TU Darmstadt
# Nov 2012
# description:
# location computation

import numpy as np

#load the dataset GTUS 2001/2002
dta = np.array(np.load('datasets/gtud.npy'), np.byte )
ref = np.array(np.load('datasets/ref.npy'))

hh=list(set(ref[:,0]))						# list of all households (HH)
loc = np.size(dta,1)					# total number of locations

conf = np.zeros((len(hh),11,11),int) # confusion matrix per user

#calculate the histogram
hst = np.zeros((11,loc),int)			# 11 activities for 10 locations

# i = number of locations
for i in range(10):	
	# u = matrix for each location
	for u in dta[:,i,:]:
		# k = timeslot, v = activity code
		for k,v in enumerate(u):		
			if (v>0):
				hst[v-1,i] += 1	

# j = HH counter
# hhid = household ID
for j, hhid in enumerate(hh):
	rw = ref[:,0] == hhid
	# init histogram
	hsta = np.array(hst)
	# change histogram according to the users activities
	# p = all users from the left-out household
	for p in dta[rw,:,:]:
		# l = location label index
		# v = actual activity label (vec) for current location and user
		for l,v in enumerate(p):
			# m = timeslot
			# w = activity label for the user
			for m,w in enumerate(v):
				if w>0:
					hsta[w-1,l] -= 1	# adjust histogram (removing the user)

	# compare user activity label with the "most common activity" from histogram
	for u in dta[rw,:,:]:
		for c,lc in enumerate(u):
			for act in lc:
				if act>0:
					conf[j,np.argmax(hsta[:,c]),act-1] += 1				
		
#save results				
np.save('conf_loc.npy',conf) 
